@@ -685,7 +685,7 @@ def importModule(resourceModuleName, muteLogs=False, reload=False, ignoreList=IG
             except Exception as innerException :
                 if not muteLogs :
                     log.warning(importResource, f'Not possible to import "{resourceModuleName}" module in the second attempt either. Original cause: {str(exception)}. Returning "{module}" by default', exception=innerException)
-        if equired and ObjectHelper.isNone(module):
+        if required and ObjectHelper.isNone(module):
             raise Exception(f'Not possible to import module: {resourceModuleName}. Check warning logs for more information')
         return module
 
@@ -704,8 +704,8 @@ def importResource(resourceName, resourceModuleName=None, muteLogs=False, reload
             except Exception as exception :
                 if not muteLogs :
                     log.warning(importResource, f'Not possible to import "{resourceName}" resource from "{resourceModuleName}" module', exception=exception)
-        if equired and ObjectHelper.isNone(resource):
-            raise Exception(f'Not possible to import resource: {resourceName}. Check warning logs for more information')
+        if required and ObjectHelper.isNone(resource):
+            raise Exception(f'Error while importing {innerResourceName} resource from {resourceModuleName} module. Resource not found. Check warning logs for more information')
         return resource
 
 def runBeforeTest(instanceList, logLevel=log.LOG, muteLogs=True):
